// Used C
#include <mega8535.h>

#ifndef	KS0108_H
#define KS0108_H

// Ports
#define LCD_CMD_PORT		PORTD		// Command Output Register
#define LCD_CMD_DIR			DDRD		// Data Direction Register for Command Port

#define LCD_DATA_IN			PINA		// Data Input Register
#define LCD_DATA_OUT		PORTA		// Data Output Register
#define LCD_DATA_DIR		DDRA		// Data Direction Register for Data Port

// Function Paramters
#define INCREMENT_X			0
#define NO_INCREMENT_X		1

// Command Port Bits
#define D_I					0x00		// D/I Bit Number
#define R_W					0x01		// R/W Bit Number
#define EN					0x02		// EN Bit Number
#define CSEL1				0x03		// CS1 Bit Number
#define CSEL2				0x04		// CS2 Bit Number

// Chips
#define CHIP1				0x00
#define CHIP2				0x01

// Commands
#define LCD_ON				0x3F
#define LCD_OFF				0x3E
#define LCD_SET_ADD			0x40
#define LCD_SET_PAGE		0xB8
#define LCD_DISP_START		0xC0

// Fill Modes
#define BLACK				0xFF
#define CLEAR				0x00

struct displayPos {
	unsigned char x;
	unsigned char y;
	unsigned char page;
};

struct font {
	unsigned char width;
	unsigned char height;
	flash char *charData;
}  ;

// Function Prototypes

// Fertig Low Level

char ks0108ReadData(unsigned char incXAdd);
void ks0108WriteCommand(unsigned char cmd, unsigned char chip);
void ks0108WriteData(unsigned char data);
void ks0108Enable(void);
          
// Fertig Mid Level
void ks0108SetInverted(unsigned char invert);
void ks0108SetDot(unsigned char, unsigned char);
void ks0108ClearDot(unsigned char, unsigned char);
void ks0108GotoXY(unsigned char, unsigned char);  
void ks0108Init(void);
void ks0108NewLine(unsigned char, unsigned char);    

// Fertig High Level

void ks0108Fill(unsigned char mode);
void ks0108Picture(flash unsigned char*);

// Fehlend
void ks0108DrawCircle(unsigned char xCenter, unsigned char yCenter, unsigned char radius);
void ks0108DrawLine(unsigned char x1, unsigned char y1, unsigned char x2, unsigned char y2);
void ks0108DrawRect(unsigned char x, unsigned char y, unsigned char width, unsigned char height);
void ks0108InvertRect(unsigned char x, unsigned char y, unsigned char width, unsigned char height);
    
// In Arbeit
void ks0108PutChar(char c, struct font font);
void ks0108PutString(char *string, struct font font);
void ks0108PutStringP(char flash *string, struct font font);

#endif
